#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

PLUGIN_NAME = 'ovs'

OVS_VHOSTUSER_INTERFACE_TYPE = 'dpdkvhostuser'
OVS_VHOSTUSER_CLIENT_INTERFACE_TYPE = 'dpdkvhostuserclient'
OVS_VHOSTUSER_PREFIX = 'vhu'

OVS_DATAPATH_SYSTEM = 'system'
OVS_DATAPATH_NETDEV = 'netdev'

PLATFORM_LINUX = 'linux2'
PLATFORM_WIN32 = 'win32'

OVS_DPDK_INTERFACE_TYPE = 'dpdk'

# Neutron dead VLAN.
DEAD_VLAN = 4095
